class AbstractHook:
    pass


class BaseaSearchHook(AbstractHook):

    def pre_search(self, *args, **kwargs):
        """
        This method allow user to prepare for starting searching vectors.
        Called before searching vectors on server.
        """
        pass

    def aft_search(self, *args, **kwargs):
        """
        Called after searching vectors on server.
        """
        pass

    def on_response(self, *args, **kwargs):
        """
        Indicate if deal with response from server.
        return bool variables.

        """
        return False

    def handle_response(self, _response):
        """
        deal with response from server and return processing results
        """
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: milvus.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from . import status_pb2 as status__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='milvus.proto',
    package='milvus.grpc',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x0cmilvus.proto\x12\x0bmilvus.grpc\x1a\x0cstatus.proto\"\x1f\n\tTableName\x12\x12\n\ntable_name\x18\x01 \x01(\t\"\'\n\rPartitionName\x12\x16\n\x0epartition_name\x18\x01 \x01(\t\"I\n\rTableNameList\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x13\n\x0btable_names\x18\x02 \x03(\t\"\x87\x01\n\x0bTableSchema\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x11\n\tdimension\x18\x03 \x01(\x03\x12\x17\n\x0findex_file_size\x18\x04 \x01(\x03\x12\x13\n\x0bmetric_type\x18\x05 \x01(\x05\"I\n\x0ePartitionParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x16\n\x0epartition_name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\"j\n\rPartitionList\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x34\n\x0fpartition_array\x18\x02 \x03(\x0b\x32\x1b.milvus.grpc.PartitionParam\"/\n\x05Range\x12\x13\n\x0bstart_value\x18\x01 \x01(\t\x12\x11\n\tend_value\x18\x02 \x01(\t\" \n\tRowRecord\x12\x13\n\x0bvector_data\x18\x01 \x03(\x02\"\x80\x01\n\x0bInsertParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x30\n\x10row_record_array\x18\x02 \x03(\x0b\x32\x16.milvus.grpc.RowRecord\x12\x14\n\x0crow_id_array\x18\x03 \x03(\x03\x12\x15\n\rpartition_tag\x18\x04 \x01(\t\"I\n\tVectorIds\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x17\n\x0fvector_id_array\x18\x02 \x03(\x03\"\xbf\x01\n\x0bSearchParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x32\n\x12query_record_array\x18\x02 \x03(\x0b\x32\x16.milvus.grpc.RowRecord\x12-\n\x11query_range_array\x18\x03 \x03(\x0b\x32\x12.milvus.grpc.Range\x12\x0c\n\x04topk\x18\x04 \x01(\x03\x12\x0e\n\x06nprobe\x18\x05 \x01(\x03\x12\x1b\n\x13partition_tag_array\x18\x06 \x03(\t\"[\n\x12SearchInFilesParam\x12\x15\n\rfile_id_array\x18\x01 \x03(\t\x12.\n\x0csearch_param\x18\x02 \x01(\x0b\x32\x18.milvus.grpc.SearchParam\"g\n\x0fTopKQueryResult\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x0f\n\x07row_num\x18\x02 \x01(\x03\x12\x0b\n\x03ids\x18\x03 \x03(\x03\x12\x11\n\tdistances\x18\x04 \x03(\x02\"H\n\x0bStringReply\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x14\n\x0cstring_reply\x18\x02 \x01(\t\"D\n\tBoolReply\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\nbool_reply\x18\x02 \x01(\x08\"M\n\rTableRowCount\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x17\n\x0ftable_row_count\x18\x02 \x01(\x03\"\x16\n\x07\x43ommand\x12\x0b\n\x03\x63md\x18\x01 \x01(\t\"*\n\x05Index\x12\x12\n\nindex_type\x18\x01 \x01(\x05\x12\r\n\x05nlist\x18\x02 \x01(\x05\"h\n\nIndexParam\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12!\n\x05index\x18\x03 \x01(\x0b\x32\x12.milvus.grpc.Index\"J\n\x11\x44\x65leteByDateParam\x12!\n\x05range\x18\x01 \x01(\x0b\x32\x12.milvus.grpc.Range\x12\x12\n\ntable_name\x18\x02 \x01(\t2\xba\t\n\rMilvusService\x12>\n\x0b\x43reateTable\x12\x18.milvus.grpc.TableSchema\x1a\x13.milvus.grpc.Status\"\x00\x12<\n\x08HasTable\x12\x16.milvus.grpc.TableName\x1a\x16.milvus.grpc.BoolReply\"\x00\x12\x43\n\rDescribeTable\x12\x16.milvus.grpc.TableName\x1a\x18.milvus.grpc.TableSchema\"\x00\x12\x42\n\nCountTable\x12\x16.milvus.grpc.TableName\x1a\x1a.milvus.grpc.TableRowCount\"\x00\x12@\n\nShowTables\x12\x14.milvus.grpc.Command\x1a\x1a.milvus.grpc.TableNameList\"\x00\x12:\n\tDropTable\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x12=\n\x0b\x43reateIndex\x12\x17.milvus.grpc.IndexParam\x1a\x13.milvus.grpc.Status\"\x00\x12\x42\n\rDescribeIndex\x12\x16.milvus.grpc.TableName\x1a\x17.milvus.grpc.IndexParam\"\x00\x12:\n\tDropIndex\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x12\x45\n\x0f\x43reatePartition\x12\x1b.milvus.grpc.PartitionParam\x1a\x13.milvus.grpc.Status\"\x00\x12\x46\n\x0eShowPartitions\x12\x16.milvus.grpc.TableName\x1a\x1a.milvus.grpc.PartitionList\"\x00\x12\x43\n\rDropPartition\x12\x1b.milvus.grpc.PartitionParam\x1a\x13.milvus.grpc.Status\"\x00\x12<\n\x06Insert\x12\x18.milvus.grpc.InsertParam\x1a\x16.milvus.grpc.VectorIds\"\x00\x12\x42\n\x06Search\x12\x18.milvus.grpc.SearchParam\x1a\x1c.milvus.grpc.TopKQueryResult\"\x00\x12P\n\rSearchInFiles\x12\x1f.milvus.grpc.SearchInFilesParam\x1a\x1c.milvus.grpc.TopKQueryResult\"\x00\x12\x37\n\x03\x43md\x12\x14.milvus.grpc.Command\x1a\x18.milvus.grpc.StringReply\"\x00\x12\x45\n\x0c\x44\x65leteByDate\x12\x1e.milvus.grpc.DeleteByDateParam\x1a\x13.milvus.grpc.Status\"\x00\x12=\n\x0cPreloadTable\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x62\x06proto3')
    ,
    dependencies=[status__pb2.DESCRIPTOR, ])

_TABLENAME = _descriptor.Descriptor(
    name='TableName',
    full_name='milvus.grpc.TableName',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.TableName.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=43,
    serialized_end=74,
)

_PARTITIONNAME = _descriptor.Descriptor(
    name='PartitionName',
    full_name='milvus.grpc.PartitionName',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='partition_name', full_name='milvus.grpc.PartitionName.partition_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=76,
    serialized_end=115,
)

_TABLENAMELIST = _descriptor.Descriptor(
    name='TableNameList',
    full_name='milvus.grpc.TableNameList',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableNameList.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_names', full_name='milvus.grpc.TableNameList.table_names', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=117,
    serialized_end=190,
)

_TABLESCHEMA = _descriptor.Descriptor(
    name='TableSchema',
    full_name='milvus.grpc.TableSchema',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableSchema.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.TableSchema.table_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='dimension', full_name='milvus.grpc.TableSchema.dimension', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index_file_size', full_name='milvus.grpc.TableSchema.index_file_size', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='metric_type', full_name='milvus.grpc.TableSchema.metric_type', index=4,
            number=5, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=193,
    serialized_end=328,
)

_PARTITIONPARAM = _descriptor.Descriptor(
    name='PartitionParam',
    full_name='milvus.grpc.PartitionParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.PartitionParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_name', full_name='milvus.grpc.PartitionParam.partition_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tag', full_name='milvus.grpc.PartitionParam.tag', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=330,
    serialized_end=403,
)

_PARTITIONLIST = _descriptor.Descriptor(
    name='PartitionList',
    full_name='milvus.grpc.PartitionList',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.PartitionList.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_array', full_name='milvus.grpc.PartitionList.partition_array', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=405,
    serialized_end=511,
)

_RANGE = _descriptor.Descriptor(
    name='Range',
    full_name='milvus.grpc.Range',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='start_value', full_name='milvus.grpc.Range.start_value', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_value', full_name='milvus.grpc.Range.end_value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=513,
    serialized_end=560,
)

_ROWRECORD = _descriptor.Descriptor(
    name='RowRecord',
    full_name='milvus.grpc.RowRecord',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='vector_data', full_name='milvus.grpc.RowRecord.vector_data', index=0,
            number=1, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=562,
    serialized_end=594,
)

_INSERTPARAM = _descriptor.Descriptor(
    name='InsertParam',
    full_name='milvus.grpc.InsertParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.InsertParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_record_array', full_name='milvus.grpc.InsertParam.row_record_array', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_id_array', full_name='milvus.grpc.InsertParam.row_id_array', index=2,
            number=3, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag', full_name='milvus.grpc.InsertParam.partition_tag', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=597,
    serialized_end=725,
)

_VECTORIDS = _descriptor.Descriptor(
    name='VectorIds',
    full_name='milvus.grpc.VectorIds',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.VectorIds.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='vector_id_array', full_name='milvus.grpc.VectorIds.vector_id_array', index=1,
            number=2, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=727,
    serialized_end=800,
)

_SEARCHPARAM = _descriptor.Descriptor(
    name='SearchParam',
    full_name='milvus.grpc.SearchParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.SearchParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='query_record_array', full_name='milvus.grpc.SearchParam.query_record_array', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='query_range_array', full_name='milvus.grpc.SearchParam.query_range_array', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='topk', full_name='milvus.grpc.SearchParam.topk', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nprobe', full_name='milvus.grpc.SearchParam.nprobe', index=4,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag_array', full_name='milvus.grpc.SearchParam.partition_tag_array', index=5,
            number=6, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=803,
    serialized_end=994,
)

_SEARCHINFILESPARAM = _descriptor.Descriptor(
    name='SearchInFilesParam',
    full_name='milvus.grpc.SearchInFilesParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='file_id_array', full_name='milvus.grpc.SearchInFilesParam.file_id_array', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='search_param', full_name='milvus.grpc.SearchInFilesParam.search_param', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=996,
    serialized_end=1087,
)

_TOPKQUERYRESULT = _descriptor.Descriptor(
    name='TopKQueryResult',
    full_name='milvus.grpc.TopKQueryResult',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TopKQueryResult.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_num', full_name='milvus.grpc.TopKQueryResult.row_num', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='ids', full_name='milvus.grpc.TopKQueryResult.ids', index=2,
            number=3, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='distances', full_name='milvus.grpc.TopKQueryResult.distances', index=3,
            number=4, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1089,
    serialized_end=1192,
)

_STRINGREPLY = _descriptor.Descriptor(
    name='StringReply',
    full_name='milvus.grpc.StringReply',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.StringReply.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='string_reply', full_name='milvus.grpc.StringReply.string_reply', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1194,
    serialized_end=1266,
)

_BOOLREPLY = _descriptor.Descriptor(
    name='BoolReply',
    full_name='milvus.grpc.BoolReply',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.BoolReply.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='bool_reply', full_name='milvus.grpc.BoolReply.bool_reply', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1268,
    serialized_end=1336,
)

_TABLEROWCOUNT = _descriptor.Descriptor(
    name='TableRowCount',
    full_name='milvus.grpc.TableRowCount',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableRowCount.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_row_count', full_name='milvus.grpc.TableRowCount.table_row_count', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1338,
    serialized_end=1415,
)

_COMMAND = _descriptor.Descriptor(
    name='Command',
    full_name='milvus.grpc.Command',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='cmd', full_name='milvus.grpc.Command.cmd', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1417,
    serialized_end=1439,
)

_INDEX = _descriptor.Descriptor(
    name='Index',
    full_name='milvus.grpc.Index',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='index_type', full_name='milvus.grpc.Index.index_type', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nlist', full_name='milvus.grpc.Index.nlist', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1441,
    serialized_end=1483,
)

_INDEXPARAM = _descriptor.Descriptor(
    name='IndexParam',
    full_name='milvus.grpc.IndexParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.IndexParam.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.IndexParam.table_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index', full_name='milvus.grpc.IndexParam.index', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1485,
    serialized_end=1589,
)

_DELETEBYDATEPARAM = _descriptor.Descriptor(
    name='DeleteByDateParam',
    full_name='milvus.grpc.DeleteByDateParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='range', full_name='milvus.grpc.DeleteByDateParam.range', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.DeleteByDateParam.table_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1591,
    serialized_end=1665,
)

_TABLENAMELIST.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLESCHEMA.fields_by_name['status'].message_type = status__pb2._STATUS
_PARTITIONLIST.fields_by_name['status'].message_type = status__pb2._STATUS
_PARTITIONLIST.fields_by_name['partition_array'].message_type = _PARTITIONPARAM
_INSERTPARAM.fields_by_name['row_record_array'].message_type = _ROWRECORD
_VECTORIDS.fields_by_name['status'].message_type = status__pb2._STATUS
_SEARCHPARAM.fields_by_name['query_record_array'].message_type = _ROWRECORD
_SEARCHPARAM.fields_by_name['query_range_array'].message_type = _RANGE
_SEARCHINFILESPARAM.fields_by_name['search_param'].message_type = _SEARCHPARAM
_TOPKQUERYRESULT.fields_by_name['status'].message_type = status__pb2._STATUS
_STRINGREPLY.fields_by_name['status'].message_type = status__pb2._STATUS
_BOOLREPLY.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLEROWCOUNT.fields_by_name['status'].message_type = status__pb2._STATUS
_INDEXPARAM.fields_by_name['status'].message_type = status__pb2._STATUS
_INDEXPARAM.fields_by_name['index'].message_type = _INDEX
_DELETEBYDATEPARAM.fields_by_name['range'].message_type = _RANGE
DESCRIPTOR.message_types_by_name['TableName'] = _TABLENAME
DESCRIPTOR.message_types_by_name['PartitionName'] = _PARTITIONNAME
DESCRIPTOR.message_types_by_name['TableNameList'] = _TABLENAMELIST
DESCRIPTOR.message_types_by_name['TableSchema'] = _TABLESCHEMA
DESCRIPTOR.message_types_by_name['PartitionParam'] = _PARTITIONPARAM
DESCRIPTOR.message_types_by_name['PartitionList'] = _PARTITIONLIST
DESCRIPTOR.message_types_by_name['Range'] = _RANGE
DESCRIPTOR.message_types_by_name['RowRecord'] = _ROWRECORD
DESCRIPTOR.message_types_by_name['InsertParam'] = _INSERTPARAM
DESCRIPTOR.message_types_by_name['VectorIds'] = _VECTORIDS
DESCRIPTOR.message_types_by_name['SearchParam'] = _SEARCHPARAM
DESCRIPTOR.message_types_by_name['SearchInFilesParam'] = _SEARCHINFILESPARAM
DESCRIPTOR.message_types_by_name['TopKQueryResult'] = _TOPKQUERYRESULT
DESCRIPTOR.message_types_by_name['StringReply'] = _STRINGREPLY
DESCRIPTOR.message_types_by_name['BoolReply'] = _BOOLREPLY
DESCRIPTOR.message_types_by_name['TableRowCount'] = _TABLEROWCOUNT
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['IndexParam'] = _INDEXPARAM
DESCRIPTOR.message_types_by_name['DeleteByDateParam'] = _DELETEBYDATEPARAM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TableName = _reflection.GeneratedProtocolMessageType('TableName', (_message.Message,), {
    'DESCRIPTOR': _TABLENAME,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableName)
})
_sym_db.RegisterMessage(TableName)

PartitionName = _reflection.GeneratedProtocolMessageType('PartitionName', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONNAME,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionName)
})
_sym_db.RegisterMessage(PartitionName)

TableNameList = _reflection.GeneratedProtocolMessageType('TableNameList', (_message.Message,), {
    'DESCRIPTOR': _TABLENAMELIST,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableNameList)
})
_sym_db.RegisterMessage(TableNameList)

TableSchema = _reflection.GeneratedProtocolMessageType('TableSchema', (_message.Message,), {
    'DESCRIPTOR': _TABLESCHEMA,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableSchema)
})
_sym_db.RegisterMessage(TableSchema)

PartitionParam = _reflection.GeneratedProtocolMessageType('PartitionParam', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionParam)
})
_sym_db.RegisterMessage(PartitionParam)

PartitionList = _reflection.GeneratedProtocolMessageType('PartitionList', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONLIST,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionList)
})
_sym_db.RegisterMessage(PartitionList)

Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), {
    'DESCRIPTOR': _RANGE,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.Range)
})
_sym_db.RegisterMessage(Range)

RowRecord = _reflection.GeneratedProtocolMessageType('RowRecord', (_message.Message,), {
    'DESCRIPTOR': _ROWRECORD,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.RowRecord)
})
_sym_db.RegisterMessage(RowRecord)

InsertParam = _reflection.GeneratedProtocolMessageType('InsertParam', (_message.Message,), {
    'DESCRIPTOR': _INSERTPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.InsertParam)
})
_sym_db.RegisterMessage(InsertParam)

VectorIds = _reflection.GeneratedProtocolMessageType('VectorIds', (_message.Message,), {
    'DESCRIPTOR': _VECTORIDS,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.VectorIds)
})
_sym_db.RegisterMessage(VectorIds)

SearchParam = _reflection.GeneratedProtocolMessageType('SearchParam', (_message.Message,), {
    'DESCRIPTOR': _SEARCHPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SearchParam)
})
_sym_db.RegisterMessage(SearchParam)

SearchInFilesParam = _reflection.GeneratedProtocolMessageType('SearchInFilesParam', (_message.Message,), {
    'DESCRIPTOR': _SEARCHINFILESPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SearchInFilesParam)
})
_sym_db.RegisterMessage(SearchInFilesParam)

TopKQueryResult = _reflection.GeneratedProtocolMessageType('TopKQueryResult', (_message.Message,), {
    'DESCRIPTOR': _TOPKQUERYRESULT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TopKQueryResult)
})
_sym_db.RegisterMessage(TopKQueryResult)

StringReply = _reflection.GeneratedProtocolMessageType('StringReply', (_message.Message,), {
    'DESCRIPTOR': _STRINGREPLY,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.StringReply)
})
_sym_db.RegisterMessage(StringReply)

BoolReply = _reflection.GeneratedProtocolMessageType('BoolReply', (_message.Message,), {
    'DESCRIPTOR': _BOOLREPLY,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.BoolReply)
})
_sym_db.RegisterMessage(BoolReply)

TableRowCount = _reflection.GeneratedProtocolMessageType('TableRowCount', (_message.Message,), {
    'DESCRIPTOR': _TABLEROWCOUNT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableRowCount)
})
_sym_db.RegisterMessage(TableRowCount)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
    'DESCRIPTOR': _COMMAND,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.Command)
})
_sym_db.RegisterMessage(Command)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {
    'DESCRIPTOR': _INDEX,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.Index)
})
_sym_db.RegisterMessage(Index)

IndexParam = _reflection.GeneratedProtocolMessageType('IndexParam', (_message.Message,), {
    'DESCRIPTOR': _INDEXPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.IndexParam)
})
_sym_db.RegisterMessage(IndexParam)

DeleteByDateParam = _reflection.GeneratedProtocolMessageType('DeleteByDateParam', (_message.Message,), {
    'DESCRIPTOR': _DELETEBYDATEPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.DeleteByDateParam)
})
_sym_db.RegisterMessage(DeleteByDateParam)

_MILVUSSERVICE = _descriptor.ServiceDescriptor(
    name='MilvusService',
    full_name='milvus.grpc.MilvusService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=1668,
    serialized_end=2878,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateTable',
            full_name='milvus.grpc.MilvusService.CreateTable',
            index=0,
            containing_service=None,
            input_type=_TABLESCHEMA,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='HasTable',
            full_name='milvus.grpc.MilvusService.HasTable',
            index=1,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_BOOLREPLY,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DescribeTable',
            full_name='milvus.grpc.MilvusService.DescribeTable',
            index=2,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_TABLESCHEMA,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CountTable',
            full_name='milvus.grpc.MilvusService.CountTable',
            index=3,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_TABLEROWCOUNT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='ShowTables',
            full_name='milvus.grpc.MilvusService.ShowTables',
            index=4,
            containing_service=None,
            input_type=_COMMAND,
            output_type=_TABLENAMELIST,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropTable',
            full_name='milvus.grpc.MilvusService.DropTable',
            index=5,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CreateIndex',
            full_name='milvus.grpc.MilvusService.CreateIndex',
            index=6,
            containing_service=None,
            input_type=_INDEXPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DescribeIndex',
            full_name='milvus.grpc.MilvusService.DescribeIndex',
            index=7,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_INDEXPARAM,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropIndex',
            full_name='milvus.grpc.MilvusService.DropIndex',
            index=8,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CreatePartition',
            full_name='milvus.grpc.MilvusService.CreatePartition',
            index=9,
            containing_service=None,
            input_type=_PARTITIONPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='ShowPartitions',
            full_name='milvus.grpc.MilvusService.ShowPartitions',
            index=10,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_PARTITIONLIST,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropPartition',
            full_name='milvus.grpc.MilvusService.DropPartition',
            index=11,
            containing_service=None,
            input_type=_PARTITIONPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Insert',
            full_name='milvus.grpc.MilvusService.Insert',
            index=12,
            containing_service=None,
            input_type=_INSERTPARAM,
            output_type=_VECTORIDS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Search',
            full_name='milvus.grpc.MilvusService.Search',
            index=13,
            containing_service=None,
            input_type=_SEARCHPARAM,
            output_type=_TOPKQUERYRESULT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='SearchInFiles',
            full_name='milvus.grpc.MilvusService.SearchInFiles',
            index=14,
            containing_service=None,
            input_type=_SEARCHINFILESPARAM,
            output_type=_TOPKQUERYRESULT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Cmd',
            full_name='milvus.grpc.MilvusService.Cmd',
            index=15,
            containing_service=None,
            input_type=_COMMAND,
            output_type=_STRINGREPLY,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteByDate',
            full_name='milvus.grpc.MilvusService.DeleteByDate',
            index=16,
            containing_service=None,
            input_type=_DELETEBYDATEPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='PreloadTable',
            full_name='milvus.grpc.MilvusService.PreloadTable',
            index=17,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_MILVUSSERVICE)

DESCRIPTOR.services_by_name['MilvusService'] = _MILVUSSERVICE

# @@protoc_insertion_point(module_scope)



from urllib.parse import urlparse
import sys
import logging
import collections
import uuid
import os

import grpc
from grpc._cython import cygrpc

from ..grpc_gen import milvus_pb2_grpc
from ..grpc_gen import milvus_pb2 as grpc_types
from .abstract import (
    ConnectIntf,
    TableSchema,
    IndexParam,
    PartitionParam
)
from .prepare import Prepare
from .types import IndexType, MetricType, Status
from .utils import (
    int_or_str,
    is_legal_host,
    is_legal_port,
)

from .hooks import BaseaSearchHook
from .client_hooks import (
    SearchHook
)

from .exceptions import ParamError, NotConnectError
from ..settings import DefaultConfig as config
from . import __version__

LOGGER = logging.getLogger(__name__)


class _ClientCallDetails(
    collections.namedtuple(
        '_ClientCallDetails',
        ('method', 'timeout', 'metadata', 'credentials', 'wait_for_ready')),
    grpc.ClientCallDetails):
    pass


class RequestIDClientInterceptor(grpc.UnaryUnaryClientInterceptor):

    def __generate_request_id(self):
        return str(uuid.uuid1()) + "-" + str(os.getpid())
        # return uuid.uuid1() + sys.os.

    def intercept_unary_unary(self, continuation, client_call_details, request):
        rid = self.__generate_request_id()
        LOGGER.info("Sending RPC request, Method: {}, Request ID: {}.".format(client_call_details.method, rid))

        # Add request into client call details, aka, metadata.
        metadata = []
        if client_call_details.metadata is not None:
            metadata = list(client_call_details.metadata)
        metadata.append(("request_id", rid))

        client_call_details = _ClientCallDetails(
            client_call_details.method, client_call_details.timeout, metadata,
            client_call_details.credentials, client_call_details.wait_for_ready)
        return continuation(client_call_details, request)


class GrpcMilvus(ConnectIntf):

    def __init__(self):
        self._channel = None
        self._stub = None
        self._uri = None
        self.status = None

        # hook
        self._search_hook = SearchHook()
        self._search_file_hook = SearchHook()

    def __str__(self):
        attr_list = ['%s=%r' % (key, value)
                     for key, value in self.__dict__.items() if not key.startswith('_')]
        return '<Milvus: {}>'.format(', '.join(attr_list))

    # def __del__(self):
    #     if self.connected():
    #         self.disconnect()

    #     if self._channel:
    #         del self._channel

    #     if self._stub:
    #         del self._stub

    # def __del__(self):

    def _set_uri(self, host=None, port=None, uri=None):
        """
        Set server network address

        """
        if host is not None:
            _port = port if port is not None else config.GRPC_PORT
            _host = host
        elif port is None:
            try:
                config_uri = urlparse(config.GRPC_URI)
                _uri = urlparse(uri) if uri else config_uri

                if _uri.scheme != 'tcp':
                    raise ParamError(
                        'Invalid parameter uri: `{}`. Scheme `{}` '
                        'is not supported'.format(_uri, _uri.scheme))

                _host = _uri.hostname
                _port = _uri.port
            except Exception:
                raise ParamError("`{}` is illegal".format(uri))
        else:
            raise ParamError("Param is not complete. Please invoke as follow:\n"
                             "\t(host = ${HOST}, port = ${PORT})\n"
                             "\t(uri = ${URI})\n")

        if not is_legal_host(_host) or not is_legal_port(_port):
            raise ParamError("host or port is illegal")

        self._uri = "{}:{}".format(str(_host), str(_port))

    def _set_channel(self, host=None, port=None, uri=None):
        """
        set grpc channel
        """
        self._set_uri(host, port, uri)

        # set transport unlimited
        self._channel = grpc.insecure_channel(
            self._uri,
            options=[(cygrpc.ChannelArgKey.max_send_message_length, -1),
                     (cygrpc.ChannelArgKey.max_receive_message_length, -1)]
        )

    def _set_hook(self, **kwargs):
        _search_hook = kwargs.get('search', None)
        if _search_hook:
            if not isinstance(_search_hook, BaseaSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_hook = _search_hook

        _search_file_hook = kwargs.get('search_in_file', None)
        if _search_file_hook:
            if not isinstance(_search_file_hook, BaseaSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_file_hook = _search_file_hook

    @property
    def server_address(self):
        """
        Server network address
        """
        return self._uri

    def connect(self, host=None, port=None, uri=None, timeout=3):
        """
        Connect method should be called before any operations.
        Server will be connected after connect return OK

        :type  host: str
        :type  port: str
        :type  uri: str
        :type  timeout: float
        :param host: (Optional) host of the server, default host is 127.0.0.1
        :param port: (Optional) port of the server, default port is 19530
        :param uri: (Optional) only support tcp proto now, default uri is

                `tcp://127.0.0.1:19530`

        :param timeout: (Optional) connection timeout, default timeout is 3000ms

        :return: Status, indicate if connect is successful
        :rtype: Status
        """
        if not self._channel:
            self._set_channel(host, port, uri)

        elif self.connected():
            return Status(message="You have already connected!", code=Status.CONNECT_FAILED)

        try:
            # check if server is ready
            grpc.channel_ready_future(self._channel).result(timeout=timeout)
            _intercept_channel = grpc.intercept_channel(self._channel, RequestIDClientInterceptor())
            self._channel = _intercept_channel
        except grpc.FutureTimeoutError:
            del self._channel
            self._channel = None
            raise NotConnectError('Fail connecting to server on {}. Timeout'.format(self._uri))
        except grpc.RpcError as e:
            del self._channel
            self._channel = None
            raise NotConnectError("Connect error: <{}>".format(e))
        # Unexpected error
        except Exception as e:
            raise NotConnectError("Error occurred when trying to connect server:\n"
                                  "\t<{}>".format(str(e)))

        self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
        self.status = Status()
        return self.status

    def connected(self):
        """
        Check if client is connected to the server

        :return: if client is connected
        :rtype: bool
        """
        if not self._stub or not self._channel:
            return False
        try:
            grpc.channel_ready_future(self._channel).result(timeout=2)
            return True
        except (grpc.FutureTimeoutError, grpc.RpcError):
            return False

    def disconnect(self):
        """
        Disconnect with the server and distroy the channel

        :return: Status, indicate if disconnect is successful
        :rtype: Status
        """
        # After closeing, a exception stack trace is printed from a background thread and
        # no exception is thrown in the main thread, issue is under test and not done yet
        # checkout https://github.com/grpc/grpc/issues/18995
        # Also checkout Properly Specify Channel.close Behavior in Python:
        # https://github.com/grpc/grpc/issues/19235
        if not self.connected():
            raise NotConnectError('Please connect to the server first!')

        # closing channel by calling interface close() will result in grpc interval error
        del self._channel

        # try:
        #     self._channel.close()
        # except Exception as e:
        #     LOGGER.error(e)
        #     return Status(code=Status.CONNECT_FAILED, message='Disconnection failed')

        self.status = None
        self._channel = None
        self._stub = None

        return Status(message='Disconnect successfully')

    def client_version(self):
        """
        Provide client version

        :return:
            version: Client version

        :rtype: (str)
        """
        return __version__

    def server_version(self, timeout=10):
        """
        Provide server version

        :return:
            Status: indicate if operation is successful

            str : Server version

        :rtype: (Status, str)
        """
        return self._cmd(cmd='version', timeout=timeout)

    def server_status(self, timeout=10):
        """
        Provide server status

        :return:
            Status: indicate if operation is successful

            str : Server version

        :rtype: (Status, str)
        """
        return self._cmd(cmd='OK', timeout=timeout)

    def _cmd(self, cmd, timeout=10):
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        cmd = Prepare.cmd(cmd)
        try:
            response = self._stub.Cmd.future(cmd).result(timeout=timeout)
            if response.status.error_code == 0:
                return Status(message='Success!'), response.string_reply

            return Status(code=response.status.error_code, message=response.status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def create_table(self, param, timeout=10):
        """
        Create table

        :type  param: dict or TableSchema
        :param param: Provide table information to be created

                `example param={'table_name': 'name',
                                'dimension': 16,
                                'index_file_size': 1024 (default)，
                                'metric_type': Metric_type.L2 (default)
                                }`

                `OR using Prepare.table_schema to create param`

        :param timeout: timeout, The unit is seconds
        :type  timeout: double

        :return: Status, indicate if operation is successful
        :rtype: Status
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_schema = Prepare.table_schema(param)

        try:
            status = self._stub.CreateTable.future(table_schema).result(timeout=timeout)
            if status.error_code == 0:
                return Status(message='Create table successfully!')

            LOGGER.error(status)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred: {}'.format(e.details()))

    def has_table(self, table_name, timeout=10):
        """

        This method is used to test table existence.

        :param table_name: table name is going to be tested.
        :type  table_name: str
        :param timeout: time waiting for server response
        :type  timeout: int

        :return:
            Status: indicate if vectors inserted successfully
            bool if given table_name exists

        """
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            reply = self._stub.HasTable.future(table_name).result(timeout=timeout)
            if reply.status.error_code == 0:
                return Status(), reply.bool_reply

            return Status(code=reply.status.error_code,
                          message=reply.status.reason), False
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="request timeout"), False
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(code=e.code(), message=e.details()), False

    def describe_table(self, table_name, timeout=10):
        """
        Show table information

        :type  table_name: str
        :param table_name: which table to be shown

        :returns: (Status, table_schema)
            Status: indicate if query is successful
            table_schema: return when operation is successful
        :rtype: (Status, TableSchema)
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            response = self._stub.DescribeTable.future(table_name).result(timeout=timeout)

            if response.status.error_code == 0:
                table = TableSchema(
                    table_name=response.table_name,
                    dimension=response.dimension,
                    index_file_size=response.index_file_size,
                    metric_type=MetricType(response.metric_type)
                )

                return Status(message='Describe table successfully!'), table

            LOGGER.error(response.status)
            return Status(code=response.status.error_code, message=response.status.reason), None

        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def count_table(self, table_name, timeout=30):
        """
        obtain vector number in table

        :type  table_name: str
        :param table_name: target table name.

        :returns:
            Status: indicate if operation is successful

            res: int, table row count
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            trc = self._stub.CountTable.future(table_name).result(timeout=timeout)
            if trc.status.error_code == 0:
                return Status(message='Success!'), trc.table_row_count

            return Status(code=trc.status.error_code, message=trc.status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def show_tables(self, timeout=10):
        """
        Show all tables information in database

        :return:
            Status: indicate if this operation is successful

            tables: list of table names, return when operation
                    is successful
        :rtype:
            (Status, list[str])
        """
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        cmd = Prepare.cmd('show_tables')
        try:
            response = self._stub.ShowTables.future(cmd).result(timeout=timeout)
            if response.status.error_code == 0:
                return Status(message='Show tables successfully!'), \
                       [name for name in response.table_names if len(name) > 0]
            return Status(response.status.error_code, message=response.status.reason), []
        except grpc.FutureTimeoutError:
            return Status(Status.UNEXPECTED_ERROR, message="Request timeout"), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), []

    def preload_table(self, table_name, timeout=300):
        """
        Load table to cache in advance

        :type table_name: str
        :param table_name: table to preload

        :returns:
            Status:  indicate if invoke is successful
        """
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            status = self._stub.PreloadTable.future(table_name).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            return Status(code=e.code(), message='Error occurred. {}'.format(e.details()))

    def drop_table(self, table_name, timeout=20):
        """
        Delete table with table_name

        :type  table_name: str
        :param table_name: Name of the table being deleted

        :return: Status, indicate if operation is successful
        :rtype: Status
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            status = self._stub.DropTable.future(table_name).result(timeout=timeout)
            if status.error_code == 0:
                return Status(message='Delete table successfully!')
            return Status(code=status.error_code, message=status.reason)

        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred: {}'.format(e.details()))

    def insert(self, table_name, records, ids=None, partition_tag=None, timeout=-1, **kwargs):
        """
        Add vectors to table

        :param ids: list of id
        :type  ids: list[int]

        :type  table_name: str
        :param table_name: table name been inserted

        :type  records: list[list[float]]

                `example records: [[1.2345],[1.2345]]`

                `OR using Prepare.records`

        :param records: list of vectors been inserted

        :type  timeout: int
        :param timeout: time waiting for server response

        :returns:
            Status: indicate if vectors inserted successfully
            ids: list of id, after inserted every vector is given a id
        :rtype: (Status, list(int))
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        insert_param = kwargs.get('insert_param', None)

        if not insert_param:
            insert_param = Prepare.insert_param(table_name, records, partition_tag, ids)
        else:
            if not isinstance(insert_param, grpc_types.InsertParam):
                raise ParamError("The value of key 'insert_param' is invalid")

        try:
            if timeout == -1:
                vector_ids = self._stub.Insert(insert_param)
            else:
                vector_ids = self._stub.Insert.future(insert_param).result(timeout=timeout)

            if vector_ids.status.error_code == 0:
                ids = list(vector_ids.vector_id_array)
                return Status(message='Add vectors successfully!'), ids

            return Status(code=vector_ids.status.error_code, message=vector_ids.status.reason), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), []
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="Request timeout"), []

    def create_index(self, table_name, index=None, timeout=-1):
        """
        build vectors of specific table and create vector index

        :param table_name: table used to crete index.
        :type table_name: str
        :param index: index params
        :type index: dict

            index_param can be None

            `example (default) param={'index_type': IndexType.FLAT,
                            'nlist': 16384}`

        :param timeout: grpc request timeout.

            if `timeout` = -1, method invoke a synchronous call, waiting util grpc response
            else method invoke a asynchronous call, timeout work here

        :type  timeout: int

        :return: Status, indicate if operation is successful
        """

        index_default = {
            'index_type': IndexType.FLAT,
            'nlist': 16384
        }
        if not index:
            _index = index_default
        elif not isinstance(index, dict):
            raise ParamError("param `index` should be a dictionary")
        else:
            _index = index
            if index.get('index_type', None) is None:
                _index.update({'index_type': IndexType.FLAT})
            if index.get('nlist', None) is None:
                _index.update({'nlist': 16384})
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        index_param = Prepare.index_param(table_name, _index)
        try:
            if timeout == -1:
                status = self._stub.CreateIndex(index_param)
            elif timeout < 0:
                raise ParamError("Param `timeout` should be a positive number or -1")
            else:
                try:
                    status = self._stub.CreateIndex.future(index_param).result(timeout=timeout)
                except grpc.FutureTimeoutError as e:
                    LOGGER.error(e)
                    return Status(Status.UNEXPECTED_ERROR, message='Request timeout')

            if status.error_code == 0:
                return Status(message='Build index successfully!')

            return Status(code=status.error_code, message=status.reason)
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def describe_index(self, table_name, timeout=10):
        """
        Show index information of designated table

        :type table_name: str
        :param table_name: table name been queried

        :returns:
            Status:  indicate if query is successful
            IndexSchema:

        """
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)

        try:
            index_param = self._stub.DescribeIndex.future(table_name).result(timeout=timeout)

            status = index_param.status

            if status.error_code == 0:
                return Status(message="Successfully"), \
                       IndexParam(index_param.table_name,
                                  index_param.index.index_type,
                                  index_param.index.nlist)

            return Status(code=status.error_code, message=status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def drop_index(self, table_name, timeout=10):
        """
        drop index from index file

        :param table_name: target table name.
        :type table_name: str

        :return:
            Status: indicate if operation is successful

        ：:rtype: Status
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        table_name = Prepare.table_name(table_name)
        try:
            status = self._stub.DropIndex.future(table_name).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def create_partition(self, table_name, partition_name, partition_tag):
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        # TODO: prepare request
        request = Prepare.partition_param(table_name, partition_name, partition_tag)

        try:
            response = self._stub.CreatePartition(request)
            return Status(code=response.error_code, message=response.reason)
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def show_partitions(self, table_name):
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        # TODO: prepare request
        request = Prepare.table_name(table_name)

        try:
            response = self._stub.ShowPartitions(request)
            status = response.status
            if status.error_code == 0:

                partition_list = []
                for partition in response.partition_array:
                    partition_param = PartitionParam(
                        partition.table_name,
                        partition.partition_name,
                        partition.tag
                    )
                    partition_list.append(partition_param
                                          )
                # TODO: return patririons list
                return Status(), partition_list

            return Status(), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(), []

    def drop_partition(self, table_name, partition_tag):
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        # TODO: prepare request
        request = Prepare.partition_param(table_name=table_name, partition_name=None, tag=partition_tag)

        try:
            response = self._stub.DropPartition(request)

            return Status(code=response.error_code, message=response.reason)
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(code=1, message="")

    def search(self, table_name, top_k, nprobe, query_records, query_ranges=None, partition_tags=None, **kwargs):
        """
        Search similar vectors in designated table

        :param table_name: target table name
        :type  table_name: str
        :param top_k: number of vertors which is most similar with query vectors
        :type  top_k: int
        :param nprobe: cell number of probe
        :type  nprobe: int
        :param query_records: vectors to query
        :type  query_records: list[list[float32]]
        :param query_ranges: query data range

        :return
            Status: indicate if search successfully
            result: query result

        :rtype: (Status, TopKQueryResult)

        """
        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        request = Prepare.search_param(
            table_name, top_k, nprobe, query_records, query_ranges, partition_tags
        )

        try:
            self._search_hook.pre_search()
            response = self._stub.Search(request)
            self._search_hook.aft_search()

            if self._search_hook.on_response():
                return response

            if response.status.error_code != 0:
                return Status(code=response.status.error_code,
                              message=response.status.reason), []

            resutls = self._search_hook.handle_response(response)
            return Status(message='Search vectors successfully!'), resutls

        except grpc.RpcError as e:
            LOGGER.error(e)
            status = Status(code=e.code(), message='Error occurred: {}'.format(e.details()))
            return status, []

    def search_in_files(self, table_name, file_ids, query_records, top_k,
                        nprobe=16, query_ranges=None, **kwargs):
        """
        Query vectors in a table, in specified files

        :type  nprobe: int
        :param nprobe:

        :type  table_name: str
        :param table_name: table name been queried

        :type  file_ids: list[str] or list[int]
        :param file_ids: Specified files id array

        :type  query_records: list[list[float]]
        :param query_records: all vectors going to be queried

        :param query_ranges: Optional ranges for conditional search.
            If not specified, search in the whole table

        :type  top_k: int
        :param top_k: how many similar vectors will be searched

        :returns:
            Status:  indicate if query is successful
            results: query result

        :rtype: (Status, TopKQueryResult)
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        file_ids = list(map(int_or_str, file_ids))

        infos = Prepare.search_vector_in_files_param(
            table_name, query_records, query_ranges, top_k, nprobe, file_ids
        )

        try:
            self._search_file_hook.pre_search()
            response = self._stub.SearchInFiles(infos)
            self._search_file_hook.aft_search()

            if self._search_file_hook.on_response():
                return response

            if response.status.error_code != 0:
                return Status(code=response.status.error_code,
                              message=response.status.reason), []

            return Status(message='Search vectors successfully!'), \
                   self._search_file_hook.handle_response(response)
        except grpc.RpcError as e:
            LOGGER.error(e)
            status = Status(code=e.code(), message='Error occurred. {}'.format(e.details()))
            return status, []

    def __delete_vectors_by_range(self, table_name, start_date=None, end_date=None, timeout=10):
        """
        Delete vectors by range. The data range contains start_time but not end_time
        This method is deprecated, not recommended for users

        :type  table_name: str
        :param table_name: str, date, datetime

        :type  start_date: str, date, datetime
        :param start_date:

        :type  end_date: str, date, datetime
        :param end_date:

        :return:
            Status:  indicate if invoke is successful
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        delete_range = Prepare.delete_param(table_name, start_date, end_date)

        try:
            status = self._stub.DeleteByRange.future(delete_range).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    # In old version of pymilvus, some methods are different from the new.
    # apply alternative method name for compatibility
    get_table_row_count = count_table
    delete_table = drop_table
    add_vectors = insert
    search_vectors = search
    search_vectors_in_files = search_in_files



import pathlib
import setuptools
import io
import re

HERE = pathlib.Path(__file__).parent

README = (HERE / 'README.md').read_text()

with io.open("milvus/client/__init__.py", "rt", encoding="utf8") as f:
    version = re.search(r'__version__ = "(.*?)"', f.read()).group(1)

setuptools.setup(
    name="pymilvus-test",
    version=version,
    description="Python Sdk for Milvus",
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/milvus-io/pymilvus',
    license="Apache-2.0",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=["grpcio>=1.22.0", "grpcio-tools>=1.22.0"],
    classifiers=[
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],

    python_requires='>=3.5'
)
